#!/bin/sh

# description: Start/Stop roulettesound
#
# This file belongs in /etc/init.d where it will be run
# on system startup and shutdown to start the roulettesound
# This program is used for repairing the database file, every
# bootup.


# This init script contains functions specific for redhat
# and mandrake init scripts.

# Source function library.
. /etc/rc.d/init.d/functions


#**************** ROULETTESOUND ******************
export eSRV_DB_SERVER_IP=127.0.0.1
export eSRV_DB_PATH=/ROULETTE_DATA.GDB
export eSRV_DB_USER=SYSDBA
export eSRV_DB_PASS=masteraloha
export eSRV_MASTER_IP=192.168.0.254

export eSOUND_SOUND_FOLDER=./AUDIO/ENG
export eSOUND_XML_RPC_PORT=6666
export eSOUND_XML_RPC_IP=127.0.0.1

export PROGRAM_FOLDER=/RouletteMaster
export PROGRAM_FILENAME=roulettesound

export DEPENDS_ON=roulettemaster


# Check if the file is there and it is executable.
if [ ! -x $PROGRAM_FOLDER/$PROGRAM_FILENAME ] 
then
	echo $"$PROGRAM_FOLDER/$PROGRAM_FILENAME does not exist or it is not an executable" 
	exit 0
fi


start(){
	if [ -z "$(ps -A |grep $DEPENDS_ON)" ] 
	then
	 	echo $"$PROGRAM_FILENAME depends on $DEPENDS_ON which is not running. Please start $DEPENDS_ON first." 
		return 0
	fi

	if [ -n "$(ps -A |grep $PROGRAM_FILENAME)" ] 
	then
	 	echo $"$PROGRAM_FILENAME is already running" 
		return 0
	fi

	echo -n $"Starting $PROGRAM_FILENAME:     "
	echo -n $"Setting volume."
	/usr/bin/amixer cset iface=MIXER,name='Master Playback Volume', 100% unmute >> ./program_snd.out 2>/dev/null 1>/dev/null
	/usr/bin/amixer cset iface=MIXER,name='Front Playback Volume', 100% unmute >> ./program_snd.out 2>/dev/null 1>/dev/null
	/usr/bin/amixer cset iface=MIXER,name='PCM Playback Volume', 100% unmute >> ./program_snd.out 2>/dev/null 1>/dev/null
	/usr/bin/amixer cset iface=MIXER,name='Center Playback Volume', 100% unmute >> ./program_snd.out 2>/dev/null 1>/dev/null
	/usr/bin/amixer cset iface=MIXER,name='Capture Volume', 0% mute >> ./program_snd.out 2>/dev/null 1>/dev/null
	/usr/bin/amixer cset iface=MIXER,name='Mic Playback Volume', 0% mute >> ./program_snd.out 2>/dev/null 1>/dev/null
	/usr/bin/amixer cset iface=MIXER,name='CD Playback Volume', 0% mute >> ./program_snd.out 2>/dev/null 1>/dev/null
	cd $PROGRAM_FOLDER
	#echo "Program start................." >> ./program_snd.out
	./$PROGRAM_FILENAME 2>/dev/null 1>/dev/null &
	RETVAL=$?
	sleep 1
	echo "Done!"

	return $RETVAL
}

stop(){
	if [ -z "$(ps -A |grep $PROGRAM_FILENAME)" ] 
	then
	 	echo $"$PROGRAM_FILENAME is not running" 
		return 0
	fi
	
	echo -n $"Stoping $PROGRAM_FILENAME:     "
	#echo "Program stop................." >> $PROGRAM_FOLDER/program_snd.out
	killall $PROGRAM_FILENAME &>/dev/null	
	RETVAL=$?
	sleep 1
	echo "Done!"
	return $RETVAL
}



# See how we were called.
case "$1" in
  start)
	start
	;;	
  stop) 
	stop
	;;
  restart|reload)
	stop
	start
	;;
  *)
	echo -n $"Usage: roulettesnd {start|stop|restart|reload|help}"
	exit 1
esac

exit $RETVAL

